# frozen_string_literal: true

# \ -s puma
require "sidekiq_unique_jobs"
require "sidekiq/pro/version"
require "sidekiq_unique_jobs/web"
require "sidekiq/pro/web"
require "sinatra/json"
require "securerandom"

# to handle liveness/readiness checks
class WebServer < ::Sinatra::Base
  get "/" do
    "containers-cp"
  end
end
url_map = {"/" => WebServer}

SSL_ENVS = %w(production staging)

# initialize sidekiq web with our configured host/port
redis_host = ENV["SIDEKIQ_REDIS_HOST"] || "localhost"
redis_port = ENV["SIDEKIQ_REDIS_PORT"] || "6379"
# rediss:// is not a typo.
# Enables SSL connection within `redis` gem.
redis_uri_scheme = SSL_ENVS.include?(ENV['RACK_ENV'])  && ENV["DEPLOYMENT_PROVIDER"].downcase == "aws" ? 'rediss://' : 'redis://'
redis_url = "#{redis_uri_scheme}#{redis_host}:#{redis_port}/1"
puts "Initializing Sidekiq web with redis url #{redis_url}"
pool = ConnectionPool.new { Redis.new(url: redis_url) }
url_map["/sidekiq"] = ::Sidekiq::Pro::Web.with(redis_pool: pool)

Sidekiq.configure_client do |config|
  config.redis = {size: 1, url: redis_url}
end

File.write(".session.key", SecureRandom.hex(32))
use Rack::Session::Cookie, secret: File.read(".session.key"), same_site: true, max_age: 86400

run Rack::URLMap.new(url_map)
